=======
Credits
=======

Creator
-------

* Aaron Bassett <aaron@rawtech.io>

Aaron's work was instrumental and so we will continue to record his name under the Creator section, however he
is no longer actively affiliated with the project.

Maintainers
-----------

* Jason Held <jasonsheld@gmail.com>

Contributors
------------
* John Sutherland - @sneeu
* Luís Rodrigues - @lfrodrigues
* @Zeioth
* Max Arnold - @max-arnold
* Marcin Zajączkowski - @szpak
* @simaojf
* Stu Dines - @sjdines
